@@ -54,8 +54,8 @@ def parse_content_range(content_range, resumed_from):
         raise ContentRangeError('Missing Content-Range')
 
     pattern = (
-        '^bytes (?P<first_byte_pos>\d+)-(?P<last_byte_pos>\d+)'
-        '/(\*|(?P<instance_length>\d+))$'
+        r'^bytes (?P<first_byte_pos>\d+)-(?P<last_byte_pos>\d+)'
+        r'/(\*|(?P<instance_length>\d+))$'
     )
     match = re.match(pattern, content_range)
 
@@ -85,8 +85,8 @@ def parse_content_range(content_range, resumed_from):
             'Invalid Content-Range returned: %r' % content_range)
 
     if (first_byte_pos != resumed_from
-        or (instance_length is not None
-            and last_byte_pos + 1 != instance_length)):
+            or (instance_length is not None
+                and last_byte_pos + 1 != instance_length)):
         # Not what we asked for.
         raise ContentRangeError(
             'Unexpected Content-Range returned (%r)'
@@ -105,7 +105,7 @@ def filename_from_content_disposition(content_disposition):
     :return: the filename if present and valid, otherwise `None`
 
     """
-    # attachment; filename=jkbrzt-httpie-0.4.1-20-g40bd8f6.tar.gz
+    # attachment; filename=jakubroztocil-httpie-0.4.1-20-g40bd8f6.tar.gz
 
     msg = Message('Content-Disposition: %s' % content_disposition)
     filename = msg.get_filename()
@@ -238,7 +238,7 @@ class Downloader(object):
         assert not self.status.time_started
 
         # FIXME: some servers still might sent Content-Encoding: gzip
-        # <https://github.com/jkbrzt/httpie/issues/423>
+        # <https://github.com/jakubroztocil/httpie/issues/423>
         try:
             total_size = int(response.headers['Content-Length'])
         except (KeyError, ValueError, TypeError):
@@ -447,8 +447,8 @@ class ProgressReporterThread(threading.Thread):
                              else 0)
 
     def sum_up(self):
-        actually_downloaded = (self.status.downloaded
-                               - self.status.resumed_from)
+        actually_downloaded = (
+            self.status.downloaded - self.status.resumed_from)
         time_taken = self.status.time_finished - self.status.time_started
 
         self.output.write(CLEAR_LINE)
