@@ -9,16 +9,16 @@ import errno
 import mimetypes
 import getpass
 from io import BytesIO
-from collections import namedtuple, Iterable
+from collections import namedtuple, Iterable, OrderedDict
 # noinspection PyCompatibility
 from argparse import ArgumentParser, ArgumentTypeError, ArgumentError
 
 # TODO: Use MultiDict for headers once added to `requests`.
-# https://github.com/jkbrzt/httpie/issues/130
+# https://github.com/jakubroztocil/httpie/issues/130
 from httpie.plugins import plugin_manager
 from requests.structures import CaseInsensitiveDict
 
-from httpie.compat import OrderedDict, urlsplit, str, is_pypy, is_py27
+from httpie.compat import urlsplit, str, is_pypy, is_py27
 from httpie.sessions import VALID_SESSION_NAME_PATTERN
 from httpie.utils import load_json_preserve_order
 
@@ -111,12 +111,13 @@ SSL_VERSION_ARG_MAPPING = {
     'tls1': 'PROTOCOL_TLSv1',
     'tls1.1': 'PROTOCOL_TLSv1_1',
     'tls1.2': 'PROTOCOL_TLSv1_2',
+    'tls1.3': 'PROTOCOL_TLSv1_3',
 }
-SSL_VERSION_ARG_MAPPING = dict(
-    (cli_arg, getattr(ssl, ssl_constant))
+SSL_VERSION_ARG_MAPPING = {
+    cli_arg: getattr(ssl, ssl_constant)
     for cli_arg, ssl_constant in SSL_VERSION_ARG_MAPPING.items()
     if hasattr(ssl, ssl_constant)
-)
+}
 
 
 class HTTPieArgumentParser(ArgumentParser):
@@ -254,8 +255,8 @@ class HTTPieArgumentParser(ArgumentParser):
                 else:
                     credentials = parse_auth(self.args.auth)
 
-                if (not credentials.has_password() and
-                        plugin.prompt_password):
+                if (not credentials.has_password()
+                        and plugin.prompt_password):
                     if self.args.ignore_stdin:
                         # Non-tty stdin read by now
                         self.error(
@@ -302,7 +303,8 @@ class HTTPieArgumentParser(ArgumentParser):
         """
         if self.args.data:
             self.error('Request body (from stdin or a file) and request '
-                       'data (key=value) cannot be mixed.')
+                       'data (key=value) cannot be mixed. Pass '
+                       '--ignore-stdin to let key/value take priority.')
         self.args.data = getattr(fd, 'buffer', fd).read()
 
     def _guess_method(self):
@@ -337,10 +339,11 @@ class HTTPieArgumentParser(ArgumentParser):
                 self.args.url = self.args.method
                 # Infer the method
                 has_data = (
-                    (not self.args.ignore_stdin and
-                     not self.env.stdin_isatty) or
-                    any(item.sep in SEP_GROUP_DATA_ITEMS
-                        for item in self.args.items)
+                    (not self.args.ignore_stdin and not self.env.stdin_isatty)
+                    or any(
+                        item.sep in SEP_GROUP_DATA_ITEMS
+                        for item in self.args.items
+                    )
                 )
                 self.args.method = HTTP_POST if has_data else HTTP_GET
 
@@ -425,8 +428,8 @@ class HTTPieArgumentParser(ArgumentParser):
         if self.args.prettify == PRETTY_STDOUT_TTY_ONLY:
             self.args.prettify = PRETTY_MAP[
                 'all' if self.env.stdout_isatty else 'none']
-        elif (self.args.prettify and self.env.is_windows and
-              self.args.output_file):
+        elif (self.args.prettify and self.env.is_windows
+                and self.args.output_file):
             self.error('Only terminal output can be colorized on Windows.')
         else:
             # noinspection PyTypeChecker
@@ -468,8 +471,8 @@ class SessionNameValidator(object):
 
     def __call__(self, value):
         # Session name can be a path or just a name.
-        if (os.path.sep not in value and
-                not VALID_SESSION_NAME_PATTERN.search(value)):
+        if (os.path.sep not in value
+                and not VALID_SESSION_NAME_PATTERN.search(value)):
             raise ArgumentError(None, self.error_message)
         return value
 
@@ -504,7 +507,7 @@ class KeyValueArgType(object):
             """Represents an escaped character."""
 
         def tokenize(string):
-            """Tokenize `string`. There are only two token types - strings
+            r"""Tokenize `string`. There are only two token types - strings
             and escaped characters:
 
             tokenize(r'foo\=bar\\baz')
